@@ -25,11 +25,12 @@ user:message_property( Dbg, Property ) :-
 
 /** <module> Debugging with calls.
 
-Avoids running goals to produce output that is only relevant while debugging.
+Debugging information focusing on avoiding running goals to produce output that is only relevant while debugging.
+
 Includes pre-canned, often used calls that print informative messages for common debugging tasks.
 
-See the main predicate's documenation, debug_call/4, for more details.<br>
-See file examples/exo.pl for a full pallette of examples. 
+See the main predicate's documenation, debug_call/4, for more details.
+See file examples/exo.pl for a full pallette of examples.
 
 ---+++ Examples
 
@@ -86,6 +87,17 @@ At 15:44:1 on 2nd of Jul 2024 finished task: write on file.
 ?- debuc(ex, simple_mess([a=1,b=2])).
 % 12
 true.
+
+?- debuc(ex, stat, runtime, true).
+% stat(runtime,[182,4]).
+true.
+
+?- debuc(ex, stat, runtime, [check_point(here),comment(false)]).
+stat(here,runtime,[193,11]).
+true.
+
+?- debuc(ex, stat, testo, [sub(true),comment(false)]).
+duh([testo-8.0K,testo/file_a-0,testo/sub_1-4.0K]).
 ==
 
 ---+++ Variable topics 
@@ -113,6 +125,7 @@ debug_calls uses dynamic =..  .
 @version 2.0 2025/10/7
 @version 2.1 2025/10/27
 @version 2.2 2025/12/8
+@version 2.3 2026/2/8
 @see debug_call/4 for information on what each version added.
 
 */
@@ -123,15 +136,20 @@ Current version and release date for the library.
 
 ==
 ?- debug_call_version( -V, -D ).
-V = 2:2:0,
-D = date(2025,12,8).
+V = 2:3:0,
+D = date(2026,2,8).
 ==
 */
-debug_call_version(2:2:0, date(2025,12,8)).
+debug_call_version(2:3:0, date(2026,2,8)).
 
-:- use_module(library(apply)).   % maplist/4,...
-:- use_module(library(lists)).   % member/4,...
-:- use_module(library(debug)).   % debug/1,...
+:- use_module(library(apply)).       % maplist/4,...
+:- use_module(library(lists)).       % member/4,...
+:- use_module(library(debug)).       % debug/1,...
+:- use_module(library(filesex)).     % directory_member/3.
+:- use_module(library(readutil)).    % read_line_to_codes/2.
+:- use_module(library(process)).     % process_create/3.
+:- use_module(library(readutil)).    % read_line_to_codes/2.
+:- use_module(library(prolog_pack)). % pack_property/2.
 :- use_module(library(lib)).
 
 :- lib(source(debug_call), [homonyms(true),index(false)]).
@@ -237,11 +255,11 @@ Particularly useful in sending uninstantiated Topics.
 
 @author nicos angelopoulos
 @version  0.1 2016/11/1
+@version  0.1 2026/1/25, avoid building the term with =.. use call/4 directly
 
 */
 debug_message( Topic, Mess, Args ) :-
-    Call =.. [debug,Topic,Mess,Args],
-    call( Call ).
+    call( debug, Topic, Mess, Args ).
 
 /** debugging_topic( ?Topic ).
 
@@ -392,8 +410,8 @@ debug_portray( Topic, Term ) :-
     portray_clause( Term ).
 debug_portray( _Topic, _Term ).
 
-%% debug_call( +Topic, +Goal, +Arg ).
-%% debug_call( +Topic, +Goal, +Arg, +Opts ).
+%% debug_call( +Topic, +DebuGoal, +Arg ).
+%% debug_call( +Topic, +DebuGoal, +Arg, +Opts ).
 %
 % Automates often used debug calls with emphasis on: (a) avoiding calling things that will not be reported and (b) easy tailoring of the messages.
 % 
@@ -449,8 +467,14 @@ debug_portray( _Topic, _Term ).
 %    As above, but Opts are passed as an extra, last argument in the call.
 %  * dims
 %    Prints the dimensions of matrix, see mtx_dims/3.
+%  * duh
+%    Short for shell command 'du -h -s' which is disc usage, summarized and in human readable form.
+%    Arg should be the directory to report the size of.
+%    Can take options check_point() and comment()- as does =|stat|=.
+%    The latter allows for reporting without '%' so terms can be read in by read/1 or consulted.
+%    In addition, option sub() can be used the subdirectories of 
 %  * end
-%    Translates to finishing ~Arg or finishing ~Topic if Arg == true.
+%    Translates to finishing ~Arg or finishing ~Topic if =|Arg==true|=.
 %  * enum
 %    Print members of lists and arguments of terms, where each item is printed on single line and prefixed by an index number
 %    Knows: depth(Depth) (restricts items to print).
@@ -460,10 +484,9 @@ debug_portray( _Topic, _Term ).
 %    Print using informational machinery (usually different/green colour, to debug's blue)
 %    term should Mess/Args in the debug/3 version
 %  * input
-% At 14:2:30 on 6th of Dec 2025 stop task: talking point
 %    Reports reading from a file. Arg should be file specification suitable for locate/3.
 %    Either loc(File,Exts) or simply File in which case Exts = ''.
-%    As of v2.0 the default is to print the basename, use path(abs) in Opts.
+%    As of v2.0 the default is to print the basename, use path(abs) in Opts if the full path to the file is needed.
 %  * length
 %    Prints the lenghts of a bunch of lists. Args should be ListNames/Lists. 
 %    uses non list ListNames if debuging the length of a single list, in which case
@@ -483,13 +506,17 @@ debug_portray( _Topic, _Term ).
 %  * options
 %    Options used on call to a predicate. Possible options: pred(Func,Ar), pred(Pid), the caller predicate, internal(true), shows also '$' starting options.
 %  * pwd 
-%    Message about current dir Location (=Arg), (if Arg == false, location is not shown)- see examples.
+%    Message about current dir Location (=Arg), (if =|Arg==false|=, location is not shown)- see examples.
 %  * read
 %    Alias for input.
 %  * session
 %    Print info on all loaded code, packs are shown with versions both from packs and info from <Pred>_version/2,3 if available (as per stoics.org.uk packs).
 %  * start 
-%    Translates to starting ~Arg or starting ~Topic if Arg == true.
+%    Translates to starting ~Arg or starting ~Topic if =|Arg==true|=.
+%  * stat
+%    Arg should be a key that can be used as the 1st arg for statistics/1, the debuc Goal reports the statistic.
+%    Can take options check_point() and comment(). 
+%    The latter allows for reporting without '%' so terms can be read in by read/1 or consulted.
 %  * task(Wch)
 %    Time of start/stop (Wch) of a task. Other values for Wch are allowed but printed as they come. 
 %    Arg can be a term (as of Version 1.5).
@@ -505,14 +532,30 @@ debug_portray( _Topic, _Term ).
 %  * wrote 
 %    Reports the writting of output on a file. Arg should be file specification suitable for locate/3.
 %    Either loc(File,Exts) or simply File in which case Exts = ''.
-%    As of v2.0 the default is to print the basename, use path(abs) in Opts.
+%    As of v2.0 the default is to print the basename, use path(abs) in Opts if the full path to the file is needed.
 %
-% As of v2.1 all debuc Goals work with options prefix(Pfx) and pred(Ar,Fn) (also synonymed to pred(Pid)).
+% As of v2.1 almosst all debuc Goals work with options prefix(Pfx) and pred(Ar,Fn) (also synonymed to pred(Pid)).
 % 
 % v2.2 introduced ability to pass formatting patterns and arguments via farg() option. 
 %
 % See file examples/exo.pl for a test suit including at least one example from each debuc Goal.
-%
+% 
+% Opts supported by all debugoals
+%  * prefix(Pfx)
+%    prefixes the message
+%  * pred(F,A)
+%    (also pred(F/A)) adds predicate caller identfication to message
+%  * farg(Farg)
+%    pass formating argument when Arg contains '~' formatting terms that expecdt an argument [task(start),task(stop)]
+% 
+% Opts for specific debugoals
+%  * check_point(Point)
+%    adds check point info to message [stat]
+%  * comment(Comm)
+%    when =|Comm==false|= print message through format without '%' (portray_message) machineary [stat- print readable terms]
+%  * depth(Depth)
+%    limits output times [enum,list]
+% 
 %==
 % ?- debug(ex).
 % 
@@ -560,13 +603,21 @@ debug_portray( _Topic, _Term ).
 %
 % ?- debuc( ex, call(list_avg_mess), [1,2,3], [pred(p1,2),prefix('By call')] ).
 % By call predicate: p1/2 avg: 2
+%
+% ?- debuc(ex, stat, runtime, true).
+% stat(runtime,[182,4]).
+% true.
+% 
+% ?- debuc(ex, stat, runtime, [check_point(here),comment(false)]).   % note this does not have a precedding percentage char
+% stat(here,runtime,[193,11]).   
+% 
 %==
 % 
 % At some point around SWI-Prolog 8, behaviour of debug/3 changed in being more strict about messages with no arguments.
 % As of version 1.2 debug_call/3 can act as a replacement of debug/3 but with the old behaviour.
 %
 %==
-% ?- debug( ex, 'Messaging...', true ).
+% ?- debug(ex, 'Messaging...', true).
 % Messaging...
 % [[ EXCEPTION while printing message 'Messaging...'
 %       with arguments user:true:
@@ -575,7 +626,7 @@ debug_portray( _Topic, _Term ).
 % 
 % true.
 % 
-% ?- debuc( ex, 'Messaging...', true ).
+% ?- debuc(ex, 'Messaging...', true).
 % % Messaging...
 % true.
 %==
@@ -592,6 +643,7 @@ debug_portray( _Topic, _Term ).
 % @version  2.0 2025/10/07  changed last two arguments, new option goal recogniser, pred/1, internal/1 & all/1
 % @version  2.1 2025/10/27  pid(F,A) & prefix() universal; call() fixed; doc; enum terms fix; ns_sel simplify
 % @version  2.2 2025/12/08  farg() option; depth() option in list and enum; debuc Goals: version, session.
+% @version  2.3             debuGoal stat; opts comment(t/f), check_point(), duh (opts as stat + sub(D))
 % @see file examples/exo.pl
 % @see debuc/3 shorthand for debug_call/3
 %
@@ -820,6 +872,29 @@ debug_call_topic( options, RepOpts, Bogs, Topic ) :-
     ),
     debug_call_message_opts( Ness, [RdcOpts], Message, Args, Bogs ),
     debug( Topic,  Message, Args ).
+debug_call_topic( duh, Dir, Bogs, Topic ) :-
+    debug_call_duh_dir( Dir, PaPair ),
+    ( memberchk(sub(true), Bogs ) ->
+          findall( Os, directory_member(Dir, Os, []), Oses ),
+          maplist( debug_call_duh_dir, Oses, SubPairs ),
+          Pairs = [PaPair|SubPairs] 
+          ; 
+          Pairs = [PaPair]
+    ),
+    ( memberchk(check_point(Point),Bogs) ->
+          Rec = duh(Point,Pairs)
+          ;
+          Rec = duh(Pairs)
+    ),
+    debuc_call_topic_term( Rec, Topic, Bogs ).
+debug_call_topic( stat, Key, Bogs, Topic ) :-
+    statistics( Key, Stat ),
+    ( memberchk(check_point(Point),Bogs) ->
+          Rec = stat(Point,Key,Stat)
+          ;
+          Rec = stat(Key,Stat)
+    ),
+    debuc_call_topic_term( Rec, Topic, Bogs ).
 debug_call_topic( term, Derm, Bogs, Topic ) :-
     ( memberchk(term_name(Tnm),Bogs) -> 
           Mess = 'Reporting term (~w): ~w',
@@ -1007,10 +1082,11 @@ debug_call_topic( input, ForLoc, Bogs, Topic ) :-
     debug_call_location_exception_message( Excp, input, Loc, MessW, Mess, Bogs, Mrgs ),
     debug_call_message_opts( Mess, Mrgs, Message, Args, Bogs ),
     debug_message( Topic, Message, Args ).
-debug_call_topic( task(Whc), Task, Bogs, Topic ) :-
+debug_call_topic( task(Whc), TaskPrv, Bogs, Topic ) :-
     datime_readable( Readable ),
     debug_call_topic_time_which_readable( Whc, Whcable ),
-    atomic_list_concat( [Readable,' ',Whcable,' task: ', Task], Mess ),
+    ( compound(TaskPrv) -> term_to_atom( TaskPrv, Task ); TaskPrv = Task ),
+    atomic_list_concat( [Readable,' ',Whcable,' task: ',Task,'.'], '', Mess ),
     debug_call_message_opts( Mess, [], Message, Args, Bogs ),
     debug_message( Topic, Message, Args ).
 debug_call_topic( start, Arg, Bogs, Topic ) :-
@@ -1076,6 +1152,14 @@ debug_call_topic_versions_predicated( [Pack-SVers|T], PVs, Topic, RemPVs ) :-
      ),
      debug_call_topic_versions_predicated( T, NxtPVs, Topic, RemPVs ).
 
+debuc_call_topic_term( Rec, Topic, Bogs ) :-
+    ( memberchk(comment(false),Bogs) ->
+          format( '~q.\n', [Rec] )
+          ;
+          debug_call_message_opts( '~w.', [Rec], Message, Args, Bogs ),
+          debug_message( Topic, Message, Args )
+     ).
+
 debug_call_topic_enum( [], _I, _Depth, _Len, _Topic ).
 debug_call_topic_enum( [H|T], I, Depth, Len, Topic ) :-
     ( I > Depth -> 
@@ -1179,3 +1263,14 @@ debug_message_prefixed_atom( Pfx, Standard, Prefixed ) :-
     downcase_atom( Fst, Low ),
     sub_atom( Standard, 1, Aft, 0, Right ),
     atomic_list_concat( [Pfx,' ',Low,Right], Prefixed ).
+
+debug_call_duh_dir( Dir, Pair ) :-
+    setup_call_cleanup(
+            process_create(path(du), ['-h','-s',Dir],
+                           [ stdout(pipe(Out))
+                           ]),
+            read_line_to_codes( Out, LineCs ),
+            close(Out)),
+    atom_codes( Line, LineCs ),
+    atomic_list_concat( [Size,Item], '\t', Line ),
+    Pair = Item-Size.
